c     TABLE OF CONTENTS:
c                       FeCalc(ipsiL, ipsiU) FeMkNorm 
c                       FePlus(fe, nuCollx,Dcollx,Dqlx,Vpar,lgFe, ivZero,nv)
c                       FeMinus(...)
c                       FeInit wrFeCA FeArrays Fecvecs mkvth FeAt0 
c                       FeMaxw(iipsi) FeConst FePrime

C     File:fe.f(or)                         ---------------------------|
C                                                                      |
C                                                                      |
      SUBROUTINE FeCalc(ipsiL, ipsiU)
c                                       compute electron distribution 
c                                       function, given quasilinear 
c                                       diffusion coefficient and 
c                                       plamsa profiles from psi index 
c                                       ipsiL to ipsiU
#include "Implic.inc"
#include "params.inc"
#include "ProfBody.inc"
#include "DqlBins.inc"
#include "FeBins.inc"
#include "RayBins.inc"
#include "WkAry.inc"
      INTEGER ipsiL, ipsiU, ip, iNotSmoo, iYesSmoo
      DATA iNotSmoo, iYesSmoo / 1 , 2 /
      EXTERNAL BrodCast, blockcpy,
     ^         FePlus, FeMinus
c
      call BrodCast(NPSIDIM * NVELDIM, fe(1,1,iITR), CONST(0.,0))
c                                       set to zero to start
      call blockcpy(ipsiU - ipsiL + 1, fe(ivZero, ipsiL, iITR), 
     ^        NVELDIM, Fenorm(ipsiL), 1)
c                                       copy normalization into 
c                                       fe(v = vpar(ivZero), psi)
      do 10 ip = ipsiL, ipsiU
        call FePlus (fe(1, ip, iITR), nuColl(1, ip),
     ^       Dcoll(1, ip), Dql(1,ip, iYesSmoo), Vpar, wkv, ivZero, nv)
c                                       solve for positive velocity
        call FeMinus(fe(1, ip, iITR), nuColl(1, ip),
     ^       Dcoll(1, ip), Dql(1,ip, iYesSmoo), Vpar, wkv, ivZero, nv)
c                                       solve for negative velocity
10    continue
      return
      END
c     -----------------------------------------------------------------
      SUBROUTINE FeMkNorm
c     determine normalized value of fe at ivZero vs psi
#include "Implic.inc"
#include "params.inc"
#include "RayBins.inc"
#include "FeBins.inc"
#include "ProfBody.inc"
      INTEGER ip
      REAL    TailFact
      TailFact = (CONST(1.,0) + TailNeps*sqrt(TailTeps))/
     ^                                        (CONST(1.,0) + TailNeps)
      do 10 ip = 1, npsi
         FeNorm(ip) = fe0 * NeAry(ip) / Vtherm(ip) * TailFact
10    continue
      return
      END
c     ----------------------------------------------------------------- 
      SUBROUTINE FePlus(fe, nuCollx, Dcollx, Dqlx, Vpar, lgFe, ivZero,
     ^     nv)
c     solve for fe for positive velocity, using the convention that
c     the new value is the old value plus the mean integrand 
c     times the delta-v to the new value
#include "Implic.inc"
#include "params.inc"
      INTEGER nv, ivZero, iv
      REAL    ExpMax, RsltMin
c     REAL    exp
      REAL
     ^        fe(nv), nuCollx(nv), lgFe(nv), 
     ^        Dcollx(nv), Dqlx(nv), Vpar(nv)
c                                       fe(ivZero) is assumed 
c                                       prescribed elsewhere
c     DATA    ExpMax / 100. /           Alpha and Ted like 85 better than 100
      DATA    ExpMax /  CONST(85.,0) /
      INTEGER DoCut6      
      DATA    DoCut6 /0/
      lgFe(ivZero) = CONST(0.,0)
      RsltMin = exp ( - ExpMax )
c     RsltMin = dexp ( - ExpMax )
      do 10 iv = ivZero, nv - 1
         lgFe(iv + 1) = lgFe(iv) + 
     ^   0.5*(nuCollx(iv+1) / (Dqlx(iv+1) + Dcollx(iv+1)) +
     ^        nuCollx(iv  ) / (Dqlx(iv  ) + Dcollx(iv  )))*
     ^        (Vpar(iv + 1) - Vpar(iv))
10    continue
      do 20 iv = ivZero + 1, nv-2
        if( lgFe(iv) .lt. ExpMax) then
          fe(iv) = fe(ivZero) * exp( - lgFe(iv) )
        else
          fe(iv) = fe(ivZero) * RsltMin
        endif
20    continue
      fe(nv-1) = CONST(0.0,0)
      fe(nv  ) = CONST(0.0,0)
      if (DoCut6 .eq. 1) then
         do iv=1,nv
            if (abs(vpar(iv)) .gt. CONST(0.6,0)) fe(iv) = CONST(0.0,0)
         enddo
      endif
      return
      END
c     ----------------------------------------------------------------- 
      SUBROUTINE FeMinus(fe, nuCollx, Dcollx, Dqlx, Vpar, lgFe, ivZero,
     ^     nv)
c     solve for fe for negative velocity, using the convention that
c     the new value is the old value plus the the mean integrand 
c     times the delta-v to the new value
#include "Implic.inc"
#include "params.inc"
      INTEGER nv, ivZero, iv
      REAL    ExpMax, RsltMin
c     REAL    exp
      REAL    
     ^        fe(nv), nuCollx(nv), Dcollx(nv), Dqlx(nv), Vpar(nv),
     ^        lgFe(nv)
c                                       solve for fe for negative velocity
c     DATA    ExpMax / 100. /           Alpha and Ted like 85 better than 100
      DATA    ExpMax /  CONST(85.,0) /
      INTEGER DoCut6      
      DATA    DoCut6 /0/
c     fe(ivZero) is assumed prescribed elsewhere
      lgFe(ivZero) = CONST(0.,0)
      RsltMin = exp ( - ExpMax )
c    ^        nuCollx(iv) / (Dqlx(iv + 1) + Dcollx(iv)) *!! Before Dec93
      do 10 iv = ivZero - 1, 1, - 1
         lgFe(iv) = lgFe(iv + 1) + 
     ^   0.5*(nuCollx(iv+1) / (Dqlx(iv+1) + Dcollx(iv+1)) +
     ^        nuCollx(iv  ) / (Dqlx(iv  ) + Dcollx(iv  )))*
     ^        (Vpar(iv) - Vpar(iv + 1))
c                                       note:  nu < 0 for iv < ivZero
10    continue
      do 20 iv = ivZero - 1, 3, -1
        if( lgFe(iv) .lt. ExpMax) then
          fe(iv) = fe(ivZero) * exp( - lgFe(iv) )
        else
          fe(iv) = fe(ivZero) * RsltMin
        endif
20    continue
      fe(1) = CONST(0.0,0)
      fe(2) = CONST(0.0,0)
      if (DoCut6 .eq. 1) then
         do iv=1,nv
            if (abs(vpar(iv)) .gt. CONST(0.6,0)) fe(iv) = CONST(0.0,0)
         enddo
      endif
      return
      END
c     ----------------------------------------------------------------- 
      SUBROUTINE FeWeight
#include "Implic.inc"
#include "params.inc"
#include "FeBins.inc"
#include "RayBins.inc"
      INTEGER iv,ip,new,old
      REAL    CtrWeght
        CtrWeght = CONST(1.,0) - WeghtItr
        new = iITR
        old = mod(iITR,2) + 1
      do 10 iv = 1, nv
      do 10 ip = 1, npsi   
        fe(iv,ip,new) = fe(iv,ip,new)*WeghtItr + 
     ^                  fe(iv,ip,old)*CtrWeght 
 10   continue
      return
      END
c     ----------------------------------------------------------------- 
      SUBROUTINE FeInit
c                                       initialize fe solver, fe
#include "Implic.inc"
      INTEGER ifirstcall
      EXTERNAL FeConst, FeArrays
      DATA    ifirstcall / 1/

      if (ifirstcall .eq. 1 ) then
        ifirstcall = 0
        call FeConst
      endif
      
      call FeArrays

      return
      END
c
c     -----------------------------------------------------------------
c
      SUBROUTINE FeArrays
      EXTERNAL mkvth, FeMkNorm, Fecvecs
      call mkvth
c                                       generate thermal velocity array 
c                                       (vthermal AND Vperpsq vs psi)
      call FeMkNorm
c                                       array of normalization for Fe 
c                                       (Fe(v = 0, psi))
      call Fecvecs
c                                       initialize collisional vectors
      return
      END
c     -----------------------------------------------------------------
      SUBROUTINE FeCvecs
c                                       initialize collisional 
c                                       diffusion and drag terms
c                                       Dcoll, nuColl with velocity bins
c                                       and psi bins.
#include "Implic.inc"
#include "params.inc"
#include "DqlBins.inc"
#include "FeBins.inc"
#include "RayBins.inc"
#include "ProfBody.inc"
      REAL    
     ^        vthsq, vth3, vth5, harg, hvpar, vpnorm, v12
      INTEGER ip, iv
      REAL TransVel, LogThing, TailT32, TailT12
      TailT12 = sqrt (TailTeps)
      TailT32 = sqrt (TailTeps) * TailTeps
      if (TailNeps * TailTeps .gt. CONST(0.0,0) ) then
        LogThing = (- log(TailNeps) - log(TailTeps)/2.) /
     ^             (CONST(1.,0)-TailTeps)
      else
        LogThing = CONST(1.0,6)
      endif
      TailVtrn = sqrt ( 2. * LogThing )
      do 20 ip = 1, npsi
         vthsq = vtherm(ip) * vtherm(ip)
         TransVel = vtherm(ip) * TailVtrn 
         vth3 = vthsq * vtherm(ip)
         vth5 = vth3 * vthsq
         nu0psi(ip) = NeAry(ip) / vth3
         do 10 iv = 1, nv
c           v12 = 0.5 * (Vpar(iv) + Vpar(iv + 1))!! removed Dec93; replaced by
c           v12 = vpar(iv)                       !! this.  Why was it here??
            v12 = vpar(iv)
            vpnorm = (v12 / vtherm(ip))
            harg = (CONST(1.,0) +  vpnorm * vpnorm)
            hvpar = CONST(1.,0) / (harg * sqrt(harg))
c           Dcoll(iv, ip) = DcollNorm * nu0psi(ip) * vthsq * hvpar Enright did
c           nuColl(iv, ip) = nuNorm * nu0psi(ip) * hvpar * v12     replace this

            Dcoll(iv, ip) = DcollNorm * nu0psi(ip) * vthsq * hvpar * 
     ^           LnlAry(ip) * BetZAry(ip)
            nuColl(iv, ip) = nuNorm * nu0psi(ip) * hvpar * v12 *
     ^           LnlAry(ip) * BetZAry(ip)
c
            if ( TailPeps .gt. CONST(0.0,0) .and.
     ^           abs(vpar(iv)) .gt. TransVel) then
                Dcoll (iv,ip) = Dcoll(iv,ip) * TailT12
                nuColl(iv,ip) = nuColl(iv,ip)* TailT32
            endif
c
10       continue
20    continue
      return
      END
c     ----------------------------------------------------------------- 
      SUBROUTINE mkVth
#include "Implic.inc"
#include "params.inc"
#include "RayBins.inc"
#include "ProfBody.inc"
#include "FeBins.inc"
      INTEGER ip
      do 10 ip = 1, npsi
         Vtherm(ip) = VthNorm * sqrt(TeAry(ip))
         VperpSq(ip) = Vtherm(ip) * Vtherm(ip)
 10   continue
      return
      END
c     -----------------------------------------------------------------
      SUBROUTINE FeAt0
c     value of fe at t = 0.
#include "Implic.inc"
#include "params.inc"
#include "RayBins.inc"
#include "FeBins.inc"
#include "ProfBody.inc"
      EXTERNAL FeMaxw
      INTEGER iipsi
c                                       initial conditions for fe(v, psi)
      do 10 iipsi = 1, npsi
         call FeMaxw(iipsi)
c                                       set fe at iipsi vs velocity
10    continue
      return
      END
c     -----------------------------------------------------------------
      SUBROUTINE FeMaxw(iipsi)
c                                       contruct Maxwell distribution 
c                                       at Psi(iipsi)
c                                       set fe at iipsi vs velocity
#include "Implic.inc"
#include "params.inc"
#include "FeBins.inc"
#include "PIetc.inc"
#include "MKSetc.inc"
      INTEGER iipsi, iv, DoCut6
      REAL    VthsInv, argument, TOOBIG
      REAL    Factor, FactorM1, TransVel, RsltMin, REXPMIN
      REAL    LoVfac, HiVfac, LoVterm, HiVterm
      DATA TOOBIG / 200. /
      DATA DoCut6/0/
c     DATA REXPMIN / 100. /           Alpha and Ted like 85 better than 100
      DATA REXPMIN /  CONST(85.,0) /
c
c  dmc 13 Jan 1995 -- replaced "100." with REXPMIN in a couple of
c  places; this avoids compiler problem under osf/1 v3.0, f77 v3.6:
c  evaluation of exp( -100. ) gave an arithmetic error.  In the TRANSP
c  environment, however, it should be noted that exp( -REXPMIN ) 
c  evaluates by silent underflow to zero.
c
c     produce Maxwellian fe(ipsi) normalized to unity (MKS units)
c     TailPeps  Regarding a ficticious fast electron tail in both
c     TailNeps  directions, the fraction eps(ilon) for Pressure, Ne and Te
c     TailTeps  such that
c     .                  TailNeps = TailPeps * TailTeps
c     .                  TailTeps = T_thermal/T_fast
c     .                  TailPeps = (n_fast T_fast)/(n_thermal T_thermal)
c     .         and
c     .              f(v) = (2 pi v_t^2)^-.5 1. n_e exp[- v^2/(2 v_t^2)]; all v
c     .         f_fast(v) = (2 pi v_f^2)^-.5 1. n_f exp[- v^2/(2 v_f^2)]; all v
c     .
c     .         where n_f/n_e = TailNeps
c     .               v_t/v_f = TailTeps^.5
c     .               n_f v_f^2 / [ n_t v_t^2 ] = TailPeps
c     .
c     TailVtrn  is the transition velocity relative to v_t at which the fast
c               electron tail becomes more important
c                        TailVtrn = v/v_t | transition
c     .                           = sqrt[2 ln(1/Neps 1/Teps^.50)/(1 - Teps^2)]
c
      VthsInv = CONST(1.,0) / (2. * Vtherm(iipsi) * Vtherm(iipsi))
      Factor  = CONST(1.,0) + sqrt(TailTeps)*TailNeps
      FactorM1= sqrt(TailTeps)*TailNeps
c     fmxnorm = 1. / (sqrt(2. * PI) * vtherm(iipsi) * CLIGHT * 1.e8)
c
      if (FactorM1 .eq. CONST(0.0,0)) then
      do 10 iv = 3, nv-2
c       fe(iv,iipsi,iITR) = fmxnorm*exp(-Vpar(iv)*Vpar(iv)*VthsInv)
        argument = Vpar(iv)*Vpar(iv)*VthsInv
        if (argument .lt. TOOBIG) then
          fe(iv,iipsi,iITR) = FeNorm(iipsi)* exp( -argument )
        else
          fe(iv,iipsi,iITR) = CONST(0.0,0)
        endif
c
10    continue
c
        fe(1   ,iipsi,iITR) = CONST(0.0,0)
        fe(2   ,iipsi,iITR) = CONST(0.0,0)
        fe(nv-1,iipsi,iITR) = CONST(0.0,0)
        fe(nv  ,iipsi,iITR) = CONST(0.0,0)
      endif
c
      if (FactorM1 .ne. CONST(0.0,0) ) then
      RsltMin = exp ( - REXPMIN )
      TransVel = vtherm(iipsi) *  sqrt ( 2. *
     ^ (- log(TailNeps) - log(TailTeps)/2.) / 
     ^                                   (CONST(1.,0)-TailTeps) )
c...
      fe(ivZero,iipsi,iITR) = CONST(0.0,0)
      LoVfac = VthSInv
      HiVfac = LoVfac * TailTeps
      do  iv = ivZero - 1, 3, - 1
        if(abs(vpar(iv)) .lt. TransVel) then
          HiVterm = vpar(iv)*LoVfac
        else
          HiVterm = vpar(iv)*HiVfac
        endif
        if(abs(vpar(iv+1)) .lt. TransVel) then
          LoVterm = vpar(iv+1)*LoVfac
        else
          LoVterm = vpar(iv+1)*HiVfac
        endif
        fe(iv,iipsi,iITR) = fe(iv+1,iipsi,iITR) +
     ^    (HiVterm + LoVterm)*(Vpar(iv)-Vpar(iv+1))
      enddo
c
      do  iv = ivZero + 1, nv-2,  1
        if(abs(vpar(iv)) .lt. TransVel) then
          HiVterm = vpar(iv)*LoVfac
        else
          HiVterm = vpar(iv)*HiVfac
        endif
        if(abs(vpar(iv-1)) .lt. TransVel) then
          LoVterm = vpar(iv-1)*LoVfac
        else
          LoVterm = vpar(iv-1)*HiVfac
        endif
        fe(iv,iipsi,iITR) = fe(iv-1,iipsi,iITR) +
     ^    (HiVterm + LoVterm)*(Vpar(iv)-Vpar(iv-1))
      enddo
      do iv = 3, nv-2
        if( fe(iv,iipsi,iITR) .lt. REXPMIN ) then
          fe(iv,iipsi,iITR) = FeNorm(iipsi)*exp(-fe(iv,iipsi,iITR))
        else
          fe(iv,iipsi,iITR) = FeNorm(iipsi) * RsltMin
        endif
      enddo
      fe(1,iipsi,iITR) = CONST(0.0,0)
      fe(2,iipsi,iITR) = CONST(0.0,0)
      fe(nv-1,iipsi,iITR) = CONST(0.0,0)
      fe(nv  ,iipsi,iITR) = CONST(0.0,0)
      endif
 
      if (DoCut6 .eq. 1) then
         do iv=1,nv
            if (abs(vpar(iv)) .gt. 0.6) fe(iv,iipsi,iITR) = CONST(0.0,0)
         enddo
      endif
      return
      END
c     ----------------------------------------------------------------- 
      SUBROUTINE FeConst
c                                       constants needed in solution of fe
c     In the Valeo-Eder paper
c     \nu_0 = \beta_z lnLambda 4 \pi e^4 n /( m^2 v_t^3)
c
c     where \beta_z is of order 1/2 and is about (1+Z)/5
c     where lnLambda is the Coulomb logarithm
c     so
c     \nu_0 = \beta_z lnLambda \cdot
c             TWOPI/5  1.6^4  3.0^1 / 9.11^2   n_{13}/(v/c)^3
#include "Implic.inc"
#include "tscunits.inc"
#include "params.inc"
#include "CGSetc.inc"
#include "MKSetc.inc"
#include "PIetc.inc"
#include "FeBins.inc"
#include "DqlBins.inc"
      VthNorm = sqrt( TeUnits * 
     ^                (ERGperEV/CONST(1.,-12)) / 
     ^                (EMASS/CONST(1.,-28)) )  /  
     ^                (CLIcgs/CONST(1.,10)) * CONST(1.,-2)
      fe0 = CONST(1.,0) / sqrt(TWOPI)
c     nu0 = betaZ * lnLambda * 4. * PI * ((ECHARG/1.e-10) ** 4) /
c    ^     ((EMASS/1.e-28) * * 2) * 1.e+16 Enright took out this for this:
      nu0 = 4. * PI * ((ECHARG/CONST(1,-10)) ** 4) /
     ^     ((EMASS/CONST(1.,-28)) * * 2) * CONST(1.,+16)

      PwrNorm = ELECMS * CLIGHT * CLIGHT * 
     ^          CONST(1.,-31) * CONST(1.,+16) *
     ^          CONST(1.,+6)
c     normalization for computation of QL power deposition 
c     (see files [FW]power.F, subroutine RFheat[Ele])
c     The heating rate is:
c     3/2 n dT/dt = \int S_w \p \eps/\p v dv^3
c     where S_w is the wave induced flux in velocity space, and 
c     where \eps is the energy per particle  == 1/2 mv^2
c     S_w = - D_{QL} \cdot \p f/\p v
c     so heating  = \int D_{QL} mv df/dv dv^1 (integrating over v-perps)
c                 = \int mc^2 (D_{QL} v d(cf)/dv dv (normalizing D and v to c)
c     The expression for PwrNorm gives mc^2 and then a conversion to m^-3
c     because f has density in it at cm-3 units.
c     
c
      nuNorm =    nu0 / ((CLIGHT * CONST(1.,10)) ** 3)
      DcollNorm = nuNorm 
      return
      END
c     -----------------------------------------------------------------
      SUBROUTINE FePrime
#include "Implic.inc"
#include "params.inc"
#include "ProfBody.inc"
#include "DqlBins.inc"
#include "FeBins.inc"
#include "RayBins.inc"
#include "WkAry.inc"
      INTEGER ips, iv
      INTEGER iNotSmoo, iYesSmoo
      DATA    iNotSmoo, iYesSmoo / 1 , 2 /
      EXTERNAL BrodCast
c
      call FePru
c     compute unsmoothed derivative
c

c
      do 10 ips = 1, npsi
        do 5 iv = 1, nv
          dfdv(iv,ips,iYesSmoo) = vpar(iv)*dfdv(iv,ips,iNotSmoo)
  5     continue
 10   continue  

      call Smooth(dfdv(1,1,iYesSmoo), 
     ^             nv, NVELDIM, npsi, nsmoo, qlsm)

c     convolve with smoothing function
c
c     NOTE: For energy conservation, the smoothing done here must
c           be identical to that done in constructing Dql.
c           Conceptually equivalent to inclusion of resonance broadening
c           in wave-particle interaction.  Loops added at 5,14,15,16
c           make smoothing over v df/dv, rather than over df/dv alone.
c
      do 20 ips = 1, npsi
         do 14 iv = 1, ivZero-1
           dfdv(iv,ips,iYesSmoo) = dfdv(iv,ips,iYesSmoo)/vpar(iv)
 14      continue
 15      dfdv(ivZero,ips,2) = CONST(0.0,0)
         do 16 iv = ivZero+1 , nv
           dfdv(iv,ips,iYesSmoo) = dfdv(iv,ips,iYesSmoo)/vpar(iv)
 16      continue
 20   continue
      return
      END
c
      SUBROUTINE FePrU
c                                       Fe Prime Unsmoothed
#include "Implic.inc"
#include "params.inc"
#include "ProfBody.inc"
#include "DqlBins.inc"
#include "FeBins.inc"
#include "RayBins.inc"
#include "WkAry.inc"
      INTEGER ips, iv
      EXTERNAL BrodCast
      do 20 ips = 1, npsi
        do 10 iv = ivZero +1, nv - 1
          dfdv(iv, ips,1) =+(fe(iv+1, ips, iITR) - fe(iv, ips, iITR)) *
     ^         dvip(iv)
 10     continue
c                                       v grid symmetery question:
c                                       make dfdv by looking out to high abs(v)
        do 11 iv = 2, ivZero -1
          dfdv(iv, ips,1) =-(fe(iv-1, ips, iITR) - fe(iv, ips, iITR)) *
     ^         dvip(iv)
 11      continue
         dfdv(ivZero, ips,1) = CONST(0.0,0)
         dfdv(nv    , ips,1) = dfdv(nv - 1, ips,1)
         dfdv( 1    , ips,1) = dfdv(     2, ips,1)
c     compute unsmoothed derivative
c     
 20   continue
      return
      END
C     fe    ends                            ---------------------------|
